@@ -7,15 +7,15 @@
 #include "collectionattributetest.h"
 #include "collectionpathresolver.h"
 
-#include "collection.h"
 #include "attributefactory.h"
+#include "collection.h"
 #include "collectioncreatejob.h"
 #include "collectiondeletejob.h"
 #include "collectionfetchjob.h"
+#include "collectionidentificationattribute.h"
 #include "collectionmodifyjob.h"
 #include "collectionrightsattribute_p.h"
 #include "control.h"
-#include "collectionidentificationattribute.h"
 
 #include "qtest_akonadi.h"
 
@@ -44,9 +44,11 @@ public:
     {
         return mData;
     }
-    void deserialize(const QByteArray &data) override {
+    void deserialize(const QByteArray &data) override
+    {
         mData = data;
     }
+
 private:
     QByteArray mData;
 };
@@ -91,23 +93,27 @@ void CollectionAttributeTest::testAttributes()
     QFETCH(QByteArray, attr2);
 
     struct Cleanup {
-        explicit Cleanup(const Collection &col) : m_col(col) {}
-        ~Cleanup() {
+        explicit Cleanup(const Collection &col)
+            : m_col(col)
+        {
+        }
+        ~Cleanup()
+        {
             // cleanup
-            CollectionDeleteJob *del = new CollectionDeleteJob(m_col);
+            auto del = new CollectionDeleteJob(m_col);
             AKVERIFYEXEC(del);
         }
         Collection m_col;
     };
 
     // add a custom attribute
-    TestAttribute *attr = new TestAttribute();
+    auto attr = new TestAttribute();
     attr->deserialize(attr1);
     Collection col;
     col.setName(QStringLiteral("attribute test"));
     col.setParentCollection(Collection(parentColId));
     col.addAttribute(attr);
-    CollectionCreateJob *create = new CollectionCreateJob(col, this);
+    auto create = new CollectionCreateJob(col, this);
     AKVERIFYEXEC(create);
     col = create->collection();
     QVERIFY(col.isValid());
@@ -117,7 +123,7 @@ void CollectionAttributeTest::testAttributes()
     QVERIFY(attr != nullptr);
     QCOMPARE(attr->serialized(), QByteArray(attr1));
 
-    CollectionFetchJob *list = new CollectionFetchJob(col, CollectionFetchJob::Base, this);
+    auto list = new CollectionFetchJob(col, CollectionFetchJob::Base, this);
     AKVERIFYEXEC(list);
     QCOMPARE(list->collections().count(), 1);
     col = list->collections().at(0);
@@ -127,7 +133,7 @@ void CollectionAttributeTest::testAttributes()
     QVERIFY(attr != nullptr);
     QCOMPARE(attr->serialized(), QByteArray(attr1));
 
-    TestAttribute *attrB = new TestAttribute();
+    auto attrB = new TestAttribute();
     attrB->deserialize(attr2);
     col.addAttribute(attrB);
     attrB = col.attribute<TestAttribute>();
@@ -145,7 +151,7 @@ void CollectionAttributeTest::testAttributes()
 
     // modify a custom attribute
     col.attribute<TestAttribute>(Collection::AddIfMissing)->deserialize(attr2);
-    CollectionModifyJob *modify = new CollectionModifyJob(col, this);
+    auto modify = new CollectionModifyJob(col, this);
     AKVERIFYEXEC(modify);
 
     list = new CollectionFetchJob(col, CollectionFetchJob::Base, this);
@@ -237,8 +243,8 @@ void CollectionAttributeTest::testDetach()
     Collection col2 = col; // and a copy, so that non-const access detaches
 
     // WHEN
-    TestAttribute *attr = col2.attribute<TestAttribute>(Akonadi::Collection::AddIfMissing);
-    TestAttribute *attr2 = col2.attribute<TestAttribute>();
+    auto *attr = col2.attribute<TestAttribute>(Akonadi::Collection::AddIfMissing);
+    auto *attr2 = col2.attribute<TestAttribute>();
 
     // THEN
     QCOMPARE(attr, attr2);
