@@ -4,13 +4,13 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "qtest_akonadi.h"
 #include "collection.h"
 #include "collectionfetchjob.h"
 #include "collectionmovejob.h"
 #include "item.h"
 #include "itemfetchjob.h"
 #include "itemfetchscope.h"
+#include "qtest_akonadi.h"
 
 #include <QHash>
 
@@ -47,7 +47,7 @@ private Q_SLOTS:
         QVERIFY(source.isValid());
         QVERIFY(destination.isValid());
 
-        CollectionMoveJob *mod = new CollectionMoveJob(source, destination, this);
+        auto mod = new CollectionMoveJob(source, destination, this);
         QVERIFY(!mod->exec());
     }
 
@@ -58,11 +58,9 @@ private Q_SLOTS:
         QTest::addColumn<bool>("crossResource");
 
         QTest::newRow("inter-resource") << Collection(AkonadiTest::collectionIdFromPath(QStringLiteral("res1")))
-                                        << Collection(AkonadiTest::collectionIdFromPath(QStringLiteral("res2")))
-                                        << true;
+                                        << Collection(AkonadiTest::collectionIdFromPath(QStringLiteral("res2"))) << true;
         QTest::newRow("intra-resource") << Collection(AkonadiTest::collectionIdFromPath(QStringLiteral("res1/foo/bla")))
-                                        << Collection(AkonadiTest::collectionIdFromPath(QStringLiteral("res1/foo/bar/bla")))
-                                        << false;
+                                        << Collection(AkonadiTest::collectionIdFromPath(QStringLiteral("res1/foo/bar/bla"))) << false;
     }
 
     // TODO: test signals
@@ -74,7 +72,7 @@ private Q_SLOTS:
         QVERIFY(source.isValid());
         QVERIFY(destination.isValid());
 
-        CollectionFetchJob *fetch = new CollectionFetchJob(source, CollectionFetchJob::Base, this);
+        auto fetch = new CollectionFetchJob(source, CollectionFetchJob::Base, this);
         AKVERIFYEXEC(fetch);
         QCOMPARE(fetch->collections().count(), 1);
         source = fetch->collections().first();
@@ -84,17 +82,17 @@ private Q_SLOTS:
         AKVERIFYEXEC(fetch);
         QHash<Collection, Item::List> referenceData;
         foreach (const Collection &c, fetch->collections()) {
-            ItemFetchJob *job = new ItemFetchJob(c, this);
+            auto job = new ItemFetchJob(c, this);
             AKVERIFYEXEC(job);
             referenceData.insert(c, job->items());
         }
 
         // move collection
-        CollectionMoveJob *mod = new CollectionMoveJob(source, destination, this);
+        auto mod = new CollectionMoveJob(source, destination, this);
         AKVERIFYEXEC(mod);
 
         // check if source was modified correctly
-        CollectionFetchJob *ljob = new CollectionFetchJob(source, CollectionFetchJob::Base);
+        auto ljob = new CollectionFetchJob(source, CollectionFetchJob::Base);
         AKVERIFYEXEC(ljob);
         Collection::List list = ljob->collections();
 
@@ -116,7 +114,7 @@ private Q_SLOTS:
             } else {
                 QCOMPARE(list[list.indexOf(it.key())].resource(), it.key().resource());
             }
-            ItemFetchJob *job = new ItemFetchJob(it.key(), this);
+            auto job = new ItemFetchJob(it.key(), this);
             job->fetchScope().fetchFullPayload();
             AKVERIFYEXEC(job);
             QCOMPARE(job->items().count(), it.value().count());
