@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Kevin Krammer <kevin.krammer@gmx.at>
+    SPDX-FileCopyrightText: 2009 Kevin Krammer <kevin.krammer@gmx.at>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef MIMETYPECHECKER_H
@@ -25,7 +12,7 @@
 #include <QSharedDataPointer>
 
 class QString;
-class QStringList;
+#include <QStringList>
 
 namespace Akonadi
 {
@@ -259,9 +246,9 @@ public:
     Q_REQUIRED_RESULT static bool isWantedCollection(const Collection &collection, const QString &wantedMimeType);
 
 private:
-    //@cond PRIVATE
+    /// @cond PRIVATE
     QSharedDataPointer<MimeTypeCheckerPrivate> d;
-    //@endcond
+    /// @endcond
 };
 
 }
