@@ -5,18 +5,18 @@
 */
 
 #include "collectionrequester.h"
-#include "entitydisplayattribute.h"
 #include "collectionfetchjob.h"
 #include "collectionfetchscope.h"
+#include "entitydisplayattribute.h"
 
-#include <QLineEdit>
 #include <KLocalizedString>
 #include <KStandardShortcut>
+#include <QLineEdit>
 
-#include <QEvent>
 #include <QAction>
-#include <QPushButton>
+#include <QEvent>
 #include <QHBoxLayout>
+#include <QPushButton>
 
 using namespace Akonadi;
 
@@ -41,7 +41,7 @@ public:
     void _k_collectionReceived(KJob *job);
     void _k_collectionsNamesReceived(KJob *job);
 
-    CollectionRequester * const q;
+    CollectionRequester *const q;
     Collection collection;
     QLineEdit *edit = nullptr;
     QPushButton *button = nullptr;
@@ -50,15 +50,17 @@ public:
 
 void CollectionRequester::Private::fetchCollection(const Collection &collection)
 {
-    CollectionFetchJob *job = new CollectionFetchJob(collection, Akonadi::CollectionFetchJob::Base, q);
+    auto job = new CollectionFetchJob(collection, Akonadi::CollectionFetchJob::Base, q);
     job->setProperty("OriginalCollectionId", collection.id());
     job->fetchScope().setAncestorRetrieval(CollectionFetchScope::All);
-    connect(job, &CollectionFetchJob::finished, q, [this](KJob *job) {_k_collectionReceived(job);});
+    connect(job, &CollectionFetchJob::finished, q, [this](KJob *job) {
+        _k_collectionReceived(job);
+    });
 }
 
 void CollectionRequester::Private::_k_collectionReceived(KJob *job)
 {
-    CollectionFetchJob *fetch = qobject_cast<CollectionFetchJob *>(job);
+    auto fetch = qobject_cast<CollectionFetchJob *>(job);
     if (!fetch) {
         return;
     }
@@ -70,10 +72,12 @@ void CollectionRequester::Private::_k_collectionReceived(KJob *job)
             currentCollection = Collection(currentCollection.parentCollection());
         }
 
-        CollectionFetchJob *namesFetch = new CollectionFetchJob(chain, CollectionFetchJob::Base, q);
+        auto namesFetch = new CollectionFetchJob(chain, CollectionFetchJob::Base, q);
         namesFetch->setProperty("OriginalCollectionId", job->property("OriginalCollectionId"));
         namesFetch->fetchScope().setAncestorRetrieval(CollectionFetchScope::Parent);
-        connect(namesFetch, &CollectionFetchJob::finished, q, [this](KJob *job) {_k_collectionsNamesReceived(job);});
+        connect(namesFetch, &CollectionFetchJob::finished, q, [this](KJob *job) {
+            _k_collectionsNamesReceived(job);
+        });
     } else {
         _k_collectionsNamesReceived(job);
     }
@@ -81,7 +85,7 @@ void CollectionRequester::Private::_k_collectionReceived(KJob *job)
 
 void CollectionRequester::Private::_k_collectionsNamesReceived(KJob *job)
 {
-    CollectionFetchJob *fetch = qobject_cast<CollectionFetchJob *>(job);
+    auto fetch = qobject_cast<CollectionFetchJob *>(job);
     const qint64 originalId = fetch->property("OriginalCollectionId").toLongLong();
 
     QMap<qint64, Collection> names;
@@ -101,7 +105,7 @@ void CollectionRequester::Private::_k_collectionsNamesReceived(KJob *job)
 
 void CollectionRequester::Private::init()
 {
-    QHBoxLayout *hbox = new QHBoxLayout(q);
+    auto hbox = new QHBoxLayout(q);
     hbox->setContentsMargins(0, 0, 0, 0);
 
     edit = new QLineEdit(q);
@@ -124,11 +128,15 @@ void CollectionRequester::Private::init()
     q->setFocusProxy(button);
     q->setFocusPolicy(Qt::StrongFocus);
 
-    q->connect(button, &QPushButton::clicked, q, [this]() { _k_slotOpenDialog(); });
+    q->connect(button, &QPushButton::clicked, q, [this]() {
+        _k_slotOpenDialog();
+    });
 
-    QAction *openAction = new QAction(q);
+    auto openAction = new QAction(q);
     openAction->setShortcut(KStandardShortcut::Open);
-    q->connect(openAction, &QAction::triggered, q, [this]() { _k_slotOpenDialog(); });
+    q->connect(openAction, &QAction::triggered, q, [this]() {
+        _k_slotOpenDialog();
+    });
 
     collectionDialog = new CollectionDialog(q);
     collectionDialog->setWindowIcon(QIcon::fromTheme(QStringLiteral("akonadi")));
