@@ -1,15 +1,15 @@
 /*
- * SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #ifndef RECENTCOLLECTIONACTION_P_H
 #define RECENTCOLLECTIONACTION_P_H
 
-#include <QStringList>
-#include <QModelIndex>
 #include "collection.h"
 #include <KSharedConfig>
+#include <QModelIndex>
+#include <QStringList>
 #include <standardactionmanager.h>
 
 class QMenu;
@@ -31,7 +31,10 @@ public:
     /**
      * Creates a new collection recent action
      */
-    explicit RecentCollectionAction(Akonadi::StandardActionManager::Type type, const Akonadi::Collection::List &selectedCollectionsList, const QAbstractItemModel *model, QMenu *menu);
+    explicit RecentCollectionAction(Akonadi::StandardActionManager::Type type,
+                                    const Akonadi::Collection::List &selectedCollectionsList,
+                                    const QAbstractItemModel *model,
+                                    QMenu *menu);
     /**
      * Destroys the collection recent action.
      */
